FlowPlayer

This will be replaced by the player.

Folliwing links jump within a playlist, requires a playlist configuration in the player. You can initialize the player with a playlist by pressing this!

Splash | Go
Honda accord | Go
Hollywood (mp3 audio) | Go
Sympathy (mp3 audio) | Go
Milton | Go

Alternative method, call playClip() - replaces the existing playlists with one clip.

Honda accord | Go
Honda accord | Go
Hollywood (mp3 audio) | Go
Sympathy (mp3 audio) | Go
Milton | Go

Play | Pause |
Stop
| Seek
Get time |
Get duration |
Get % loaded |
Replace playlist! | Back to original playlist!
Set some cuePoints

Events: